@@ -1,16 +1,16 @@
-if [ ! -f /etc/unbound/icannbundle.pem ]
+if [ ! -e /etc/unbound/icannbundle.pem ]
 then
     /usr/bin/mkdir -p /etc/unbound
     /usr/bin/cp /etc/defaults/etc/unbound/icannbundle.pem /etc/unbound/icannbundle.pem
 fi
 
-if [ ! -f /etc/unbound/unbound.conf ]
+if [ ! -e /etc/unbound/unbound.conf ]
 then
     /usr/bin/mkdir -p /etc/unbound
     /usr/bin/cp /etc/defaults/etc/unbound/unbound.conf /etc/unbound/unbound.conf
 fi
 
-if [ ! -f /var/lib/unbound/root.key ]
+if [ ! -e /var/lib/unbound/root.key ]
 then
     /usr/bin/mkdir -p /var/lib/unbound
     /usr/bin/cp /etc/defaults/var/lib/unbound/root.key /var/lib/unbound/root.key
